@@ -6,7 +6,7 @@ use warnings;
 
 use FileHandle;
 
-our $VERSION = '1.1.2';
+our $VERSION = '1.02';
 
 =head1 NAME
 
@@ -270,7 +270,7 @@ sub readRecord {
   $memo=''	unless defined($memo);
   $memo.=$m;
  }
- $memo=~s/( +|\00+)$//	if $memo;
+ $memo=~s/( +|\00+)\z//	if $memo;
  push @Data, $memo;
 
  return 1;
